@@ -55,9 +55,8 @@ function(coordinates,genotypes,#data
                        as.integer(nloc),
                        as.integer(nindiv),
                        as.integer(nloc),
-                       as.integer(allele.numbers),
                        as.integer(nallmax),
-                       as.double(delta.coord),
+                       as.single(delta.coord),
                        as.integer(nit/thinning),
                        as.character(filenpp),
                        as.character(filenpop),
@@ -67,16 +66,16 @@ function(coordinates,genotypes,#data
                        as.character(filefperm),
                        as.character(filedom),
                        as.character(filedomperm),
-                       as.double(t(coordinates)),
-                       as.double(u),
+                       as.single(t(coordinates)),
+                       as.single(u),
                        as.integer(c),
-                       as.double(dom),
-                       as.double(domperm),
-                       as.double(coorddom),
+                       as.single(dom),
+                       as.single(domperm),
+                       as.single(coorddom),
                        as.integer(indvois),
-                       as.double(distvois),
-                       as.double(f11),
-                       as.double(orderf11))
+                       as.single(distvois),
+                       as.single(f11),
+                       as.single(orderf11))
     param <- c(paste("nxdom :",nxdom),
                paste("nydom :",nydom))
     write.table(param,file=paste(path.mcmc,"postprocess.parameters.txt",sep=""),
@@ -95,14 +94,14 @@ function(coordinates,genotypes,#data
     out.res<- .Fortran(name="pppmindiv",
                        PACKAGE="Geneland",
                        as.integer(nindiv),
-                       as.double(t(coordinates)),
+                       as.single(t(coordinates)),
                        as.integer(npopmax),
                        as.integer(nb.nuclei.max),
                        as.integer(indvois),
-                       as.double(distvois),
-                       as.double(u),
+                       as.single(distvois),
+                       as.single(u),
                        as.integer(c),
-                       as.double(pmp),
+                       as.single(pmp),
                        as.character(filenpp),
                        as.character(fileu),
                        as.character(filec),
