@@ -1,45 +1,48 @@
 "mcmcFmodel" <-
 function(
                                         # input data
-                 coordinates,genotypes,ploidy=2,
-                 # path to output directory
-                 path.mcmc,
-                 # hyper-prior parameters
-                 rate.max,delta.coord,npopmin,npopinit,npopmax,
-                 # dimensions
-                 nb.nuclei.max,
-                 # options in mcmc computations
-                 nit,thinning=1,freq.model="Dirichlet",varnpop,spatial=TRUE)
+                       coordinates,genotypes,allele.numbers=NULL,ploidy=2,
+                                        # path to output directory
+                       path.mcmc,
+                                        # hyper-prior parameters
+                       rate.max,delta.coord,npopmin,npopinit,npopmax,
+                                        # dimensions
+                       nb.nuclei.max,
+                                        # options in mcmc computations
+                       nit,thinning=1,freq.model="Dirichlet",varnpop,spatial=TRUE,
+                       jcf=TRUE)
   {
     ## check parameters
     if((nit %% thinning) != 0)
       {
         stop('nit/thinning is not an integer')
       }
-                                        # next lines don't work under M$-Windows
-                                        #     if(file.exists(path.mcmc) != TRUE)
-                                        #       {
-                                        #         stop('The output directory does not exist')
-                                        #       }
-    
 
     ##
     ## Reformatting data
     if(ploidy == 1)
       {
         ## diploidize the data
+##         if(!is.null(allele.numbers))
+##           {
+##             allele.numbers.tmp <- rep(NA,ncol(genotypes)*2)
+##             allele.numbers.tmp[seq(1,ncol(genotypes)*2-1,2)] <- allele.numbers
+##             allele.numbers.tmp[seq(2,ncol(genotypes)*2,2)] <- allele.numbers
+##             allele.numbers <- allele.numbers.tmp
+##           }
         data.tmp <- matrix(nrow=nrow(genotypes),
                             ncol=ncol(genotypes)*2)
         data.tmp[,seq(1,ncol(genotypes)*2-1,2)] <- genotypes
         data.tmp[,seq(2,ncol(genotypes)*2,2)] <- genotypes
         genotypes <- data.tmp
+ 
       }
     data.tmp <- FormatGenotypes(as.matrix(genotypes))
     coordinates <- as.matrix(coordinates)
     genotypes <- data.tmp$genotypes
-    allele.numbers <- data.tmp$allele.numbers
+    if(is.null(allele.numbers)) {allele.numbers <- data.tmp$allele.numbers}
+
 
-    
 
     ##
     ## Initializing variables
@@ -56,7 +59,7 @@ function(
     filet <-  paste(path.mcmc,"hidden.coord.txt",sep="")
     filelpp <- paste(path.mcmc,"log.posterior.density.txt",sep="")
     filell <- paste(path.mcmc,"log.likelihood.txt",sep="")
-
+ 
 
     nindiv <- nrow(genotypes)
     nloc <- length(allele.numbers)
@@ -90,14 +93,18 @@ function(
     listcell <- rep(times=nb.nuclei.max,-999)
     fmodel <- ifelse(freq.model=="Falush",1,0) # Falush or Dirichlet model
     kfix <- 1-as.integer(varnpop)
-    spatial <- as.integer(spatial)
+
+    ## set seeds of RNG
+    seed1 <- floor(runif(1)*2147483647)
+    seed2 <-  floor(runif(1)*2147483647)
+#    spatial <- as.integer(spatial)
 
     ##
     ## Starting MCMC computations
 
     out.res<- .Fortran(name="mcmc",
                        PACKAGE="Geneland",
-                       as.double(t(coordinates)),
+                       as.single(t(coordinates)),
                        as.integer(genotypes),
                        as.integer(allele.numbers),
                        as.integer(ploidy),
@@ -112,8 +119,8 @@ function(
                        as.character(filet),
                        as.character(filelpp),
                        as.character(filell),
-                       as.double(rate.max),
-                       as.double(delta.coord),
+                       as.single(rate.max),
+                       as.single(delta.coord),
                        as.integer(nit),
                        as.integer(thinning),
                        as.integer(nindiv),
@@ -125,32 +132,33 @@ function(
                        as.integer(npopinit),
                        as.integer(npopmin),
                        as.integer(npopmax),
-                       as.double(t),
-                       as.double(ttemp),
-                       as.double(u),
-                       as.double(utemp),
+                       as.single(t),
+                       as.single(ttemp),
+                       as.single(u),
+                       as.single(utemp),
                        as.integer(c),
                        as.integer(ctemp),
-                       as.double(f),
-                       as.double(ftemp),
-                       as.double(fa),
-                       as.double(drift),
-                       as.double(drifttemp),
+                       as.single(f),
+                       as.single(ftemp),
+                       as.single(fa),
+                       as.single(drift),
+                       as.single(drifttemp),
                        as.integer(indcell),
                        as.integer(indcelltemp),
-                       as.double(distcell),
-                       as.double(distcelltemp),
+                       as.single(distcell),
+                       as.single(distcelltemp),
                        as.integer(n),
                        as.integer(ntemp),
-                       as.double(a),
-                       as.double(ptemp),
-                       as.integer(effcl),
-                       as.integer(iclv),
+                       as.single(a),
+                       as.single(ptemp),
                        as.integer(cellclass),
                        as.integer(listcell),
                        as.integer(fmodel),
                        as.integer(kfix),
-                       as.integer(spatial))
+                       as.integer(spatial),
+                       as.integer(jcf),
+                       as.integer(seed1),
+                       as.integer(seed2))
 
                                         # write parameters of the present run in an ascii file
     param <- c(#paste("path.mcmc :",path.mcmc),
