@@ -1,28 +1,27 @@
       subroutine  postprocesschain(nindivmax,nxdommax,nydommax,burn,
-     &     nclassmax,nppmax,
-     &     nlocmax,nindiv,nloc,nall,nallmax,dt,nchain,filenpp,
-     &     filenclass,fileu,filec,filef,filefperm,filedom,filedomperm,
+     &     npopmax,nppmax,
+     &     nlocmax,nindiv,nloc,nallmax,dt,nchain,filenpp,
+     &     filenpop,fileu,filec,filef,filefperm,filedom,filedomperm,
      &     s,u,c,dom,domperm,coorddom,indvois,distvois,f,orderf)
       implicit none
 
-      character*256 files,fileu,filec,filenpp,
-     &     filenclass,filedom,filedomperm,filenall,filef,filefperm
+      character*256 fileu,filec,filenpp,
+     &     filenpop,filedom,filedomperm,filef,filefperm
       
-      integer nchain,npp,nclass,ichain,nindiv,nindivmax,nxdommax,
-     &     nydommax,nclassmax,ipp,nppmax,c,ixdom,iydom,idom,indvois,
-     &     iclass,nloc, nlocmax,nall,nallmax,ijunk,orderf,iindiv,iloc,
-     &     iclassperm,burn
+      integer nchain,npp,npop,ichain,nindiv,nindivmax,nxdommax,
+     &     nydommax,npopmax,ipp,nppmax,c,ixdom,iydom,idom,indvois,
+     &     ipop,nloc, nlocmax,nallmax,ijunk,orderf,ipopperm,burn
       real s,u,xlim(2),ylim(2),coorddom,dom,domperm,distvois,f,dt
 
 *     dimensionnement 
 *     PENSER AU FORMAT D ECRITURE DES FREQUENCES 
-*     QUI DEPEND DE NCLASSMAX
+*     QUI DEPEND DE NPOPMAX
       dimension s(2,nindivmax),u(2,nppmax),c(nppmax),
-     &     dom(nxdommax*nydommax,nclassmax),
-     &     domperm(nxdommax*nydommax,nclassmax),
+     &     dom(nxdommax*nydommax,npopmax),
+     &     domperm(nxdommax*nydommax,npopmax),
      &     coorddom(2,nxdommax*nydommax),indvois(nxdommax*nydommax),
-     &     distvois(nxdommax*nydommax),nall(nlocmax),f(nclassmax),
-     &     orderf(nclassmax)
+     &     distvois(nxdommax*nydommax),f(npopmax),
+     &     orderf(npopmax)
       
 
 **************************
@@ -50,15 +49,15 @@ c            write(6,*) 'iydom=',iydom
      &           float(ixdom-1)*(xlim(2) - xlim(1))/float(nxdommax-1)
             coorddom(2,idom) = ylim(1) +
      &           float(iydom-1)*(ylim(2) - ylim(1))/float(nydommax-1)
-            do iclass=1,nclassmax
-               dom(idom,iclass) = 0.
-               domperm(idom,iclass) = 0.
+            do ipop=1,npopmax
+               dom(idom,ipop) = 0.
+               domperm(idom,ipop) = 0.
             enddo
             idom = idom + 1
          enddo
       enddo
 
-      open(9,file=filenclass)
+      open(9,file=filenpop)
       open(10,file=filenpp)
       open(11,file=fileu)
       open(12,file=filec)
@@ -69,10 +68,10 @@ c            write(6,*) 'iydom=',iydom
 
 
       do ichain=1,nchain
- 100     format(f7.3,' %')
+c 100     format(f7.3,' %')
 c         write(6,100)float(ichain)/float(nchain)*100.
          
-         read(9,*) nclass
+         read(9,*) npop
          
          read(10,*) npp
          do ipp=1,nppmax
@@ -81,13 +80,13 @@ c         write(6,100)float(ichain)/float(nchain)*100.
          enddo
          
          read(13,*) f
-         call indexx(nclass,nclassmax,f,orderf)
+         call indexx(npop,npopmax,f,orderf)
          
-         write(14,2000) (f(orderf(iclass)),iclass=1,nclassmax)
+         write(14,2000) (f(orderf(ipop)),ipop=1,npopmax)
          
          do ijunk=2,nallmax*nloc
             read(13,*) f
-            write(14,2000) (f(orderf(iclass)),iclass=1,nclassmax)
+            write(14,2000) (f(orderf(ipop)),ipop=1,npopmax)
          enddo
          
          
@@ -97,19 +96,19 @@ c         write(6,100)float(ichain)/float(nchain)*100.
          
          if(ichain .gt. burn)  then
             do idom=1,nxdommax*nydommax
-               iclass = c(indvois(idom))
-               iclassperm = orderf(c(indvois(idom)))
-               dom(idom,iclass) =  dom(idom,iclass) + 1.
-               domperm(idom,iclassperm) = domperm(idom,iclassperm) + 1.
+               ipop = c(indvois(idom))
+               ipopperm = orderf(c(indvois(idom)))
+               dom(idom,ipop) =  dom(idom,ipop) + 1.
+               domperm(idom,ipopperm) = domperm(idom,ipopperm) + 1.
             enddo
          endif
       enddo
 
 
       do idom=1,nxdommax*nydommax
-         do iclass=1,nclassmax
-            dom(idom,iclass) = dom(idom,iclass)/float(nchain-burn)
-            domperm(idom,iclass) = domperm(idom,iclass)/
+         do ipop=1,npopmax
+            dom(idom,ipop) = dom(idom,ipop)/float(nchain-burn)
+            domperm(idom,ipop) = domperm(idom,ipop)/
      &           float(nchain-burn)
          enddo
       enddo
@@ -117,8 +116,8 @@ c         write(6,100)float(ichain)/float(nchain)*100.
  2000 format (1000(f8.3,1x))
 
       do idom=1,nxdommax*nydommax
-         write(15,2000) (dom(idom,iclass), iclass=1,nclassmax)
-         write(16,2000) (domperm(idom,iclass), iclass=1,nclassmax)
+         write(15,2000) (dom(idom,ipop), ipop=1,npopmax)
+         write(16,2000) (domperm(idom,ipop), ipop=1,npopmax)
       enddo
       
       close(9)
@@ -144,10 +143,8 @@ c         write(6,100)float(ichain)/float(nchain)*100.
      &     nit,burn
       real pmp,distcell,u,s
 
-      integer iit,ipp,iindiv,nppcur,ccur,ipop
-      real xlim(2),ylim(2),ucur,dt
-      character*256 files,fileu,filec,filenpp,
-     &     filenclass,filedom,filedomperm,filenall,filef,filefperm
+      integer iit,ipp,iindiv,ipop
+      character*256 fileu,filec,filenpp,filenpop
       
 
       dimension indcell(nindiv),distcell(nindiv),
@@ -164,7 +161,7 @@ c         write(6,100)float(ichain)/float(nchain)*100.
 
 *     sequentially processes states of the chain
       do iit=1,nit
-10000    format(f7.3,' %')
+c10000    format(f7.3,' %')
 c         write(6,10000)float(iit)/float(nit)*100.
          
          read(10,*) npp
